@@ -9,17 +9,19 @@ summary.mHMM <- function(object, ...){
   m       <- input$m
   q_emiss <- input$q_emiss
   n_dep   <- input$n_dep
-  gamma_pop <- matrix(round(apply(object$gamma_prob_bar[((burn_in + 1): J),], 2, median),3), byrow = TRUE, ncol = m, nrow = m)
+  gamma_int <- matrix(apply(object$gamma_int_bar[((burn_in + 1): J),], 2, median), byrow = TRUE, ncol = m-1, nrow = m)
+  gamma_pop <- round(int_to_prob(gamma_int),3)
   colnames(gamma_pop) <- paste("To state", 1:m)
   rownames(gamma_pop) <- paste("From state", 1:m)
   cat("State transition probability matrix","\n",  "(at the group level):", "\n", "\n")
   print(gamma_pop)
   cat("\n", "\n")
   cat("Emission distribution for each of the dependent variables","\n",  "(at the group level):", "\n", "\n")
-  EM_pop <- vector("list", n_dep)
+  EM_int <- EM_pop <- vector("list", n_dep)
   names(EM_pop) <- dep_labels
   for(i in 1:n_dep){
-    EM_pop[[i]] <- matrix(round(apply(object$emiss_prob_bar[[i]][((burn_in + 1): J),], 2, median),3), byrow = TRUE, ncol = q_emiss[i], nrow = m)
+    EM_int[[i]] <- matrix(apply(object$emiss_int_bar[[i]][((burn_in + 1): J),], 2, median), byrow = TRUE, ncol = q_emiss[i]-1, nrow = m)
+    EM_pop[[i]] <- round(int_to_prob(EM_int[[i]]),3)
     colnames(EM_pop[[i]]) <- paste("Category", 1:q_emiss[i])
     rownames(EM_pop[[i]]) <- paste("State", 1:m)
   }
